pub enum TypeKind {
}Variants
Dyn(Empty)
Null(i32)
Primitive(i32)
Wrapper(i32)
WellKnown(i32)
ListType(Box<ListType>)
MapType(Box<MapType>)
Function(Box<FunctionType>)
MessageType(String)
TypeParam(String)
Type(Box<Type>)
Error(Empty)
AbstractType(AbstractType)
Implementations
Sourceimpl TypeKind
impl TypeKind
Sourcepub fn merge(
field: &mut Option<TypeKind>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<TypeKind>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.