pub struct HttpStatus {
pub code: i32,
}Fields
code: i32Implementations
Sourceimpl HttpStatus
impl HttpStatus
Sourcepub fn code(&self) -> StatusCode
pub fn code(&self) -> StatusCode
Returns the enum value of code, or the default if the field is set to an invalid enum value.
Sourcepub fn set_code(&mut self, value: StatusCode)
pub fn set_code(&mut self, value: StatusCode)
Sets code to the provided enum value.